@@ -79,6 +79,9 @@ def load_config_file(filename, default_filename=None,
     config = _config_env.copy()
     for fname in [default_filename, filename]:
         if fname and os.path.exists(fname):
+            if not os.path.isfile(fname):
+                die("config file path '%s' exists but is not a file !"
+                    % (fname, ))
             try:
                 with open(fname) as f:
                     code = compile(f.read(), fname, 'exec')
@@ -89,7 +92,7 @@ def load_config_file(filename, default_filename=None,
                     % (fname, e.lineno, e.offset))
         else:
             if fail_if_not_present:
-                die('%r config file is not found and is required.' % (filename, ))
+                die('%s config file is not found and is required.' % (fname, ))
 
     return config
 
@@ -160,7 +163,6 @@ def paragraph_wrap(text, regexp="\n\n"):
 ##
 
 
-
 def cmd(command, env=None):
     p = Popen(command, shell=True,
               stdin=PIPE, stdout=PIPE, stderr=PIPE,
@@ -263,7 +265,7 @@ class GitCommit(SubGitObjectMixin):
         aformat = "%x00".join(GIT_FORMAT_KEYS[l]
                               for l in missing_attrs)
         try:
-            ret = self.swrap("git show -s %s --pretty=format:%s"
+            ret = self.swrap("git show -s %s --pretty=format:%s --"
                              % (identifier, aformat))
         except ShellError:
             raise ValueError("Given commit identifier %s doesn't exists"
@@ -448,7 +450,7 @@ class GitRepos(object):
         aformat = "%x00".join(GIT_FORMAT_KEYS.values())
         try:
             ret = self.swrap(
-                "git log %r -z --first-parent --pretty=format:%s"
+                "git log %r -z --first-parent --pretty=format:%s --"
                 % (start, aformat))
         except ShellError:
             raise ValueError("Given commit identifier %r doesn't exists"
